| Title: | The Entire Transcript from Friends in Tidy Format |
|---|---|
| Description: | The complete scripts from the American sitcom Friends in tibble format. Use this package to practice data wrangling, text analysis and network analysis. |
| Authors: | Emil Hvitfeldt [aut, cre] (ORCID: <https://orcid.org/0000-0002-0679-1945>) |
| Maintainer: | Emil Hvitfeldt <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-11 09:11:02 UTC |
| Source: | https://github.com/emilhvitfeldt/friends |
Each season consists of episodes, each episode is divided into scenes, each scene comprises utterances. One utterance per row. Emotion annotation is included when available.
friendsfriends
A tibble with 67359 rows and
6)' variables:
text, speaker, season, episode,
scene and utterance.
https://github.com/emorynlp/character-mining
This tibble contains the emotions for the utterances where it is available.
friends_emotionsfriends_emotions
A tibble with 12606
rows an5)' variables:
season, episode, scene, utterance and
entities.
https://github.com/emorynlp/character-mining
https://github.com/emorynlp/emotion-detection
This tibble contains the character entities for the utterances where it is available.
friends_entitiesfriends_entities
A tibble with 10557
rows an5)' variables:
season, episode, scene, utterance and
entities.
https://github.com/emorynlp/character-mining
This tibble contains additional information about each of the episodes. Information was sourced from Wikipedia and IMDb on August 26th, 2020.
friends_infofriends_info
A tibble with 236 rows
an8)' variables:
season, episode, title, directed_by,
written_by, air_date, us_views_millions and
imdb_rating.
https://en.wikipedia.org/wiki/Friends
https://www.imdb.com/title/tt0108778/